# TerminalGPT

Welcome to terminalGPT, the terminal-based ChatGPT personal assistant app!
With terminalGPT, you can easily interact with the OpenAI GPT 3.5 language model.

Whether you need help with a quick question or want to explore a complex topic, TerminalGPT is here to assist you. Simply enter your query and TerminalGPT will provide you with the best answer possible based on its extensive knowledge base.

![Alt Text](./usage.gif)

## Why?

Some advantages of using TerminalGPT over the chatGPT browser-based app:

1. It doesn't disconnect like the browser-based app, so you can leave it running in a terminal session on the side without losing context.
2. It's highly available and can be used whenever you need it.
3. It's faster with replies than the browser-based app.
4. You can use TerminalGPT with your IDE terminal, which means you won't have to constantly switch between your browser and your IDE when you have questions.
5. TerminalGPT's answers are tailored to your machine's operating system, distribution, and chip set architecture.

## Pre-requisites

1. Python 3.6 or higher
2. An OpenAI Account and API key (It's free for personal use).
[How to create OpenAI API keys](https://elephas.app/blog/how-to-create-openai-api-keys-cl5c4f21d281431po7k8fgyol0)

## Installation

1. Install the latest TerminalGPT with pip install.

```sh
pip install terminalgpt -U
```

2. Now you have `terminalgpt` command available in your terminal. Run the following command to configure the app.

```sh
terminalgpt install
```

3. Enter your OpenAI API key when prompted and press enter.


That's it! You're ready to use TerminalGPT!

---

## Usage

1. Run the program with the following command:

```sh
terminalgpt chat
```
